==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/kjsembed/kjsembed/image.h <==
/* This file is part of the KDE libraries
    Copyright (C) 2005, 2006 KJSEmbed Authors
    See included AUTHORS file.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef IMAGE_H
#define IMAGE_H

#include "value_binding.h"
#include "static_binding.h"

class QImage;

namespace KJSEmbed
{
    /** @internal Implements the bniding for QImage. */
    class ImageBinding : public ValueBinding
    {
        public:
            ImageBinding( KJS::ExecState *exec, const QImage &value );
        private:
            virtual const KJS::ClassInfo* classInfo() const { return &info; }
            static const KJS::ClassInfo info;
    };

    /**
    * Constructors:
    *
    * Methods:
    */
    KJS_BINDING( Image )
}
#endif

//kate: indent-spaces on; indent-width 4; replace-tabs on; indent-mode cstyle;

==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/kjsembed/kjsembed/image.h <==
/* This file is part of the KDE libraries
    Copyright (C) 2005, 2006 KJSEmbed Authors
    See included AUTHORS file.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef IMAGE_H
#define IMAGE_H

#include "variant_binding.h"
#include "static_binding.h"

class QImage;

namespace KJSEmbed
{
    /** @internal Implements the bniding for QImage. */
    class ImageBinding : public VariantBinding
    {
        public:
            ImageBinding( KJS::ExecState *exec, const QImage &value );
            virtual const KJS::ClassInfo* classInfo() const { return &info; }
            static const KJS::ClassInfo info;
    };

    /**
    * Constructors:
    *
    * Methods:
    */
    KJS_BINDING( Image )
}
#endif

//kate: indent-spaces on; indent-width 4; replace-tabs on; indent-mode cstyle;
